
// bibhtml: Generates HTML page (with images) from BibTex files
// See: https://www.telecom-paris.fr/~elc/software/
//
// Copyright 2020 Eric Lecolinet (eric.lecolinet@gmail.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "bib.hpp"
#include "extension.hpp"

/// MUST BE FIRST!
std::list<BibExtension*> Bib::extensions;

BibExtension::BibExtension(Bib& btw) {
  Bib::extensions.push_back(this);
}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// YOUR OWN EXTENSIONS HERE

TelecomExtension telecomExtension(Bib::instance);

TelecomExtension::TelecomExtension(Bib& btw)
: BibExtension(btw) {}

void TelecomExtension::completeEntry(Bib&, BibEntry& ref) {
  // specific to the Telecom "annote" field
  const std::string& annote = ref.field(BibFields::annote);
  if (annote.empty()) return;
  std::stringstream ss(annote);
  std::string keyword, keyval;
  
  while (ss.good()) {
    getline(ss, keyword, '=');
    ccuty::strtrim(keyword);
    ss >> keyval;
    
    switch (ccuty::strid(keyword)) {
      case ccuty::strid("documentURL"):
        if (!keyval.empty()) ref.setParsedField(BibFields::pdf, keyval);
        break;
      case ccuty::strid("doi"):   // complete doi link if needed
        if (!keyval.empty()) {
          if (keyval.compare(0, 4, "http") == 0)
          ref.setParsedField(BibFields::doi, keyval);
        else
          ref.setParsedField(BibFields::doi, BibSettings::DoiPrefix + keyval);
        }
        break;
      case ccuty::strid("language"):
        if (!keyval.empty()) ref.setParsedField(BibFields::language, keyval);
        break;
      case ccuty::strid("state"):
        if (keyval.empty()) ref.setParsedField(BibFields::pubstate, "unknown state");
        else if (keyval != "published") ref.setParsedField(BibFields::pubstate, keyval);
        break;
    }
  }
}
